Package: rfordummies
Title: Code Examples to Accompany the Book "R for Dummies"
Version: 0.1.6
Authors@R: c(person("Andrie", "de Vries", role=c("aut", "cre"),
    email="apdevries@gmail.com"), person("Joris", "Meys", role =
    c("aut")))
Description: Contains all the code examples in the book "R for Dummies" (2nd
    edition) by Andrie de Vries and Joris Meys. You can view the table of 
    contents as well as the sample code for each chapter.
Language: en-US
URL: https://rfordummies.com,
        https://rfordummies.github.io/rfordummies/
BugReports: https://github.com/rfordummies/rfordummies/issues
Suggests: fortunes, stringr, sos, reshape2, ggplot2, foreign, lattice,
        covr, testthat, spelling
License: GPL-2 | GPL-3
LazyData: true
RoxygenNote: 7.1.2
Encoding: UTF-8
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2022-02-25 17:00:23 UTC; apdev
Author: Andrie de Vries [aut, cre],
  Joris Meys [aut]
Maintainer: Andrie de Vries <apdevries@gmail.com>
Repository: CRAN
Date/Publication: 2022-02-25 23:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 21:51:12 UTC; unix
